@@ -1,7 +1,8 @@
 # Arguments validation for freq, ctable, descr and dfSummary functions.
 # Another function for validating st_options arguments follows.
-#' @importFrom checkmate test_int test_logical test_choice test_string
+#' @importFrom checkmate test_int test_logical test_choice test_string test_number
 #' @importFrom dplyr n_distinct
+#' @importFrom stats na.omit
 #' @keywords internal
 check_args <- function(mc, dotArgs) {
   
@@ -228,6 +229,34 @@ check_args <- function(mc, dotArgs) {
                                len = 2, unique = TRUE))) {
       errmsg %+=% "'dnn' must be a character vector of 2 distinct values"
     }
+    
+    if ("OR" %in% names(mc)) {
+      if (isTRUE(pf$OR)) {
+        pf$OR <- .95
+      } else {
+        if (!test_number(pf$OR, na.ok = TRUE, lower = .5, upper = .999)) {
+          errmsg %+=% "'OR' must be a number between .5 and .999"
+        }
+        if (length(as.numeric(na.omit(unique(pf$x)))) != 2 ||
+            length(as.numeric(na.omit(unique(pf$y)))) != 2) {
+          errmsg %+=% "'OR' can only be used with 2 x 2 tables"
+        }
+      }
+    }
+    
+    if ("RR" %in% names(mc)) {
+      if (isTRUE(pf$RR)) {
+        pf$RR <- .95
+      } else {
+        if (!test_number(pf$RR, na.ok = TRUE, lower = .5, upper = .999)) {
+          errmsg %+=% "'RR' must be a number between .5 and .999"
+        }
+        if (length(as.numeric(na.omit(unique(pf$x)))) != 2 ||
+            length(as.numeric(na.omit(unique(pf$y)))) != 2) {
+          errmsg %+=% "'RR' can only be used with 2 x 2 tables"
+        }
+      }
+    }
   }
   
   # descr arguments ------------------------------------------------------------
